@@ -33,8 +33,10 @@ I.ABS_LINES = [ ...
 'to handle cases without lines. Can be given in two ways:', ...
 '#1. As a file name. All formats handled by arts can then be used. See', ...
 ' ABS_LINES_FORMAT. The reading is not restricted to any frequency range.', ...
-'#2. As an array of line data. This option is only allowed when ',...
-'ABS_LINES_FORMAT is set to ''Arts''.'
+'#2. For the XML option, several file names can be given (as string array)',...
+' and the line data in the files are appended.',...
+'#3. As an array of line data. This option is only allowed when ',...
+'ABS_LINES_FORMAT is set to ''XML''.'
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_LINES_FLIMS = {};
@@ -51,9 +53,9 @@ I.ABS_LINES_FLIMS = [ ...
 Q.ABS_LINES_FORMAT = {};
 I.ABS_LINES_FORMAT = [ ...
 'The format of spectroscopic data.', ...
-'#   Possible line formats are ''Arts'', ''Hitran'', ''Jpl'' and ',...
-'''Mytran2''. Note that these strings must be given exactly as stated here ',...
-'(first upper case etc.).',...
+'#   Possible line formats are ''XML'', ''Artscat'', ''Hitran'', ''Jpl'' and ',...
+'''Mytran2''. The first option (XML) expects the ABS_LINES is line data',...
+'including meta data (i.e. the system inroduced 2020).',...
 '#   The field can further be set to ''None'' which indicates that no line ',...
 'data shall be included (the WSV *abs_lines_per_species* is set to be empty).'
 ];
@@ -62,13 +64,13 @@ Q.ABS_LINESHAPE = {};
 I.ABS_LINESHAPE = [ ...
 'The line shape to use. The same line shape is used for all tag groups.', ...
 ' Shall be a string. ', ...
-'Do "arts -d abs_lineshapeDefine" to list valid options.'
+'Do "arts -d abs_linesSetLineShapeType" to list valid options.'
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_LINESHAPE_CUTOFF = {};
 I.ABS_LINESHAPE_CUTOFF = [ ...
 'The line shape cut-off to apply. The same cut-off is used for all tag', ...
-' groups. A value of -1 means no cut-off. ', ...
+' groups. A value of <0 means no cut-off. ', ...
 'Do "arts -d abslineshapeDefine" for further information.'
 ];
 %-----------------------------------------------------------------------------
@@ -76,7 +78,13 @@ Q.ABS_LINESHAPE_FACTOR = {};
 I.ABS_LINESHAPE_FACTOR = [ ...
 'The line shape normalisation factor to apply. The same factor is used', ...
 ' for all tag groups. Shall be a string. ', ...
-'Do "arts -d abs_lineshapeDefine" for valid options.'
+'Do "arts -d abs_linesSetNormalization" for valid options.'
+];
+%-----------------------------------------------------------------------------
+Q.ABS_LINESHAPE_MIRRORING = {};
+I.ABS_LINESHAPE_MIRRORING = [ ...
+'Option for mirroring of lines.', ...
+'Do "arts -d abs_linesSetMirroring" for valid options.'
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_LOOKUP = {};
@@ -155,6 +163,11 @@ I.ABS_SPECIES = [ ...
 'match the grid field. Data must match <UNIT>. A matrix, that can be ',...
 'sparse.',...
 '# ',...
+'#<SXINV> The inverse of SX. An optional field. If set, a matrix of same ',...
+'size as SX. Otherwise the inverse is calculated internally. A reason to '.... 
+'set this field is if the inverse can be determined by an analytical ',...
+'espression.',...
+'# ',...
 '#<L2> Flag for any function creating L2 data. See comments for ',...
 '*L2_EXTRA*. If set to true, the retrieved state for the species ',...
 'will be included in the L2 output. Otherwise not. This field has no ',...
@@ -183,13 +196,18 @@ I.ABS_SPECIES = [ ...
 'covariance and gain matrices are kept consistent with the original ',...
 'retrieval grids.'...
 '# ',...
-'#<MINMAX> Min and max allowed value for retrievals. A single min and ',...
+'#<MINMAX> Min and max allowed value for retrievals. This field has ',...
+'no impact on linear retrievals. These limits are applied during the ',...
+'iterations of a non-linear inversion. The limits apply also to the ',...
+'final result for inversions that converge, but not always for non-',...
+'converging inversions,',...    
+'#   A single min and ',...
 'max value is applied for each species. The field can be left undefined, ',...
 'be empty, be a scalar or vector of length 2. A single value as taken as ',...
 'min, and is then set to Inf. The min value can be set to -Inf. The unit',...
 'follows the field *UNIT*.',...
 '# The primary usage of the field should be to avoid negative vmr values. ',...
-'(The limits are applied also during the iterations of a non-linear inversion.'
+'# ',...
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_T = {};
@@ -270,11 +288,6 @@ I.BATCH = [ ...
 'must be selected specifically (most easily done by using *arts_batch*).' 
 ];
 %-----------------------------------------------------------------------------
-Q.BLACKBODY_RADIATION_AGENDA = {};
-I.BLACKBODY_RADIATION_AGENDA = [ ...
-'As the arts WSV with the same name. WSMs are listed as an array of strings.'
-];
-%-----------------------------------------------------------------------------
 Q.CLOUDBOX = {};
 I.CLOUDBOX = [ ...
 'Handling of cloudbox/scattering. Defined by a structure, described in ',...
@@ -310,6 +323,8 @@ I.FSHIFTFIT = [ ...
 '# ',...
 '#<SX> Variance of a priori knowledge on the variable.',...
 '# ',...
+'#<SXINV> The inverse of SX. An optional field, see further ABS_SPECIES.',...
+'# ',...
 '#<L2> Flag for any function creating L2 data. See comments for ',...
 '*L2_EXTRA*. If set to true, the retrieved frequency fit variables ',...
 'will be included in the L2 output. Otherwise not. This field has no ',...
@@ -329,6 +344,8 @@ I.FSTRETCHFIT = [ ...
 '# ',...
 '#<SX> Variance of a priori knowledge on the variable.',...
 '# ',...
+'#<SXINV> The inverse of SX. An optional field, see further ABS_SPECIES.',...
+'# ',...
 '#<L2> Flag for any function creating L2 data. See comments for ',...
 '*L2_EXTRA*. If set to true, the retrieved frequency fit variables ',...
 'will be included in the L2 output. Otherwise not. This field has no ',...
@@ -488,6 +505,30 @@ I.MAG_U = [ ...
 'data of climatology character. Can be given as a variable or a file saved ',...
 'through *gf_save*. ',...
 'This field is recognised and used automatically by Qpack2.',...
+'# ',...
+'#<RETRIEVE> If set to true, this magnetic field component is retrieved.', ...
+'# ',...
+'#<GRIDS> Retrieval grids for the component. An array of vectors of length 3:',...
+' {p_grid,lat_grid,lon_grid}. Grids for dimensions not used shall be ',...
+'empty.',...
+'# ',...
+'#<SX> Covariance matrix of a priori knowledge. Size must ',...
+'match the grid field. Data must match <UNIT>. A matrix, that can be ',...
+'sparse.',...
+'# ',...
+'#<SXINV> The inverse of SX. An optional field, see further ABS_SPECIES.',...
+'# ',...
+'#<L2> Flag for any function creating L2 data. See comments for ',...
+'*L2_EXTRA*. If set to true, the retrieved state for this component ',...
+'will be included in the L2 output. Otherwise not.',...
+'# ',...
+'#<L2_RANGE>  As the same field for ABS_SPECIES.',...
+'# ',...
+'#<MINMAX> Min and max allowed value for retrievals. Works exactly as ',...
+'for ABS_SPECIES.',...
+'# ',...
+'#None of the fields are mandatory for pure forward calculations. If ',...
+'RETRIEVAL is set to false, the other retrieval related fields are ignored.'
 ];
 %-----------------------------------------------------------------------------
 Q.MAG_V_FIELD = {};
@@ -516,26 +557,15 @@ I.MAG_W = [ ...
 'Defined as MAG_U, and the details are nor repeated here.'
 ];
 %-----------------------------------------------------------------------------
-Q.MBLOCK_AA_GRID = {};
-I.MBLOCK_AA_GRID = [ ...
-'Has the same functionality as the arts WSV with the same name. ', ...
-'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
-'#   If the antenna dimension is 1, this variable can be left as {}. ', ...
-'For 2D antennas it has to be set even if the sensor does not include an ', ...
-'antenna.', ...
-'#   Can be given either as the name of a file, as a matching Matlab ',...
-'variable or control file text.'
-];
-%-----------------------------------------------------------------------------
-Q.MBLOCK_ZA_GRID = {};
-I.MBLOCK_ZA_GRID = [ ...
+Q.MBLOCK_DLOS_GRID = {};
+I.MBLOCK_DLOS_GRID = [ ...
 'Has the same functionality as the arts WSV with the same name. ', ...
 'This has to be set even if the sensor does not include an antenna.', ...
 '#   Can be given either as the name of a file, as a matching Matlab ',...
 'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
-Q.OUTPUT_FILE_FORMAT = {};
+Q.OUTPUT_FILE_FORMAT = 'binary';
 I.OUTPUT_FILE_FORMAT = [ ...
 'As the arts WSV with the same name. That is, the format for files created ',...
 'by arts. Possible options are ''binary'' and ''ascii''. The binary option ',...
@@ -562,11 +592,13 @@ I.POINTING = [ ...
 '#<POLY_ORDER> Order of polynomial to describe the time variation of ',...
 'pointing errors.', ...
 '# ',...
-'#<CALCMODE> The manner in which the jacobian is determined. See  used WSM',...
+'#<CALCMODE> The manner in which the jacobian is determined. See used WSM.',...
 '# ',...
 '#<SX> Covariance matrix of a priori knowledge for pointing fit variables. ',...
 'A square matrix of size POLY_ORDER+1.',...
 '# ',...
+'#<SXINV> The inverse of SX. An optional field, see further ABS_SPECIES.',...
+'# ',...
 '#<L2> Flag for any function creating L2 data. See comments for ',...
 '*L2_EXTRA*. If set to true, the retrieved pointing variables ',...
 'will be included in the L2 output. Otherwise not. This field has no ',...
@@ -591,6 +623,8 @@ I.POLYFIT = [ ...
 '#<SXn> Covariance matrix of a priori knowledge for coefficient of order ',...
 'POLY_ORDER. The last required covariance matrix.',...
 '# ',...
+'#<SXINVn> The inverse of SXn. An optional field, see further ABS_SPECIES.',...
+'# ',...
 '#<L2> Flag for any function creating L2 data. See comments for ',...
 '*L2_EXTRA*. If set to true, the retrieved baseline variables ',...
 'will be included in the L2 output. Otherwise not. This field has no ',...
@@ -657,6 +691,21 @@ I.REFR_INDEX_AIR_AGENDA = [ ...
 'As the arts WSV with the same name. WSMs are listed as an array of strings.'
 ];
 %-----------------------------------------------------------------------------
+Q.RTE_LOS = {};
+I.RTE_LOS = [ ...
+'As the arts WSV with the same name.'
+];
+%-----------------------------------------------------------------------------
+Q.RTE_POS = {};
+I.RTE_POS = [ ...
+'As the arts WSV with the same name.'
+];
+%-----------------------------------------------------------------------------
+Q.RTE_POS2 = {};
+I.RTE_POS2 = [ ...
+'As the arts WSV with the same name.'
+];
+%-----------------------------------------------------------------------------
 Q.SENSOR_DO = {};
 I.SENSOR_DO = [ ...
 'Boolean to include sensor characteristics. Otherwise monochromatic pencil ',...
@@ -672,6 +721,11 @@ I.SENSOR_LOS = [ ...
 'As the arts WSV with the same name.'
 ];
 %-----------------------------------------------------------------------------
+Q.SENSOR_POL = {};
+I.SENSOR_POL = [ ...
+'As the arts WSV with the same name.'
+];
+%-----------------------------------------------------------------------------
 Q.SENSOR_POS = {};
 I.SENSOR_POS = [ ...
 'As the arts WSV with the same name.'
@@ -683,27 +737,27 @@ I.SENSOR_RESPONSE = [ ...
 '#1: The first option is to specify each variable associated with the ',...
 'sensor individually. This field can then be the name of a XML file or ',...
 'a Matlab sparse matrix. Other fields that must be specified for this ',...
-'option include: ANTENNA_DIM, MBLOCK_ZA/AA_GRID and ',...
-'SENSOR_RESPONSE_F/ZA/AA/POL.',...
+'option include: ANTENNA_DIM, MBLOCK_DLOS_GRID and ',...
+'SENSOR_RESPONSE_F/DLOS/POL.',...
 '#2: The name of control files to include (ARTS_INCLUDES recognised). ',...
 'Given as an array of strings.',...
 '#3: Calculate the response from basic data. This field shall then be a ',...
 'structure, following the definitions in *qartsSensor*. Type ',...
 '''qinfo(@qartsSensor);'' for definition of required data fields.',...
 'Other fields that must/may be specified here include ANTENNA_DIM and ',...
-'MBLOCK_ZA/AA_GRID.'
+'MBLOCK_DLOS_GRID.'
 ];
 %-----------------------------------------------------------------------------
-Q.SENSOR_RESPONSE_AA = {};
-I.SENSOR_RESPONSE_AA = [ ...
+Q.SENSOR_RESPONSE_DLOS = {};
+I.SENSOR_RESPONSE_DLOS = [ ...
 'As the arts WSV with the same name. ', ...
 'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
 '#   Can be given either as the name of a file, as a matching Matlab ',...
 'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
-Q.SENSOR_RESPONSE_AA_GRID = {};
-I.SENSOR_RESPONSE_AA_GRID = [ ...
+Q.SENSOR_RESPONSE_DLOS_GRID = {};
+I.SENSOR_RESPONSE_DLOS_GRID = [ ...
 'As the arts WSV with the same name. ', ...
 'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
 '#   Can be given either as the name of a file, as a matching Matlab ',...
@@ -742,22 +796,6 @@ I.SENSOR_RESPONSE_POL_GRID = [ ...
 'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
-Q.SENSOR_RESPONSE_ZA = {};
-I.SENSOR_RESPONSE_ZA = [ ...
-'As the arts WSV with the same name. ', ...
-'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
-'#   Can be given either as the name of a file, as a matching Matlab ',...
-'variable or control file text.'
-];
-%-----------------------------------------------------------------------------
-Q.SENSOR_RESPONSE_ZA_GRID = {};
-I.SENSOR_RESPONSE_ZA_GRID = [ ...
-'As the arts WSV with the same name. ', ...
-'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
-'#   Can be given either as the name of a file, as a matching Matlab ',...
-'variable or control file text.'
-];
-%-----------------------------------------------------------------------------
 Q.SENSOR_TIME = {};
 I.SENSOR_TIME = [ ...
 'As the arts WSV with the same name.'
@@ -785,6 +823,8 @@ I.SINEFIT = [ ...
 '#<SXn> Covariance matrix of a priori knowledge for last period length. ',...
 'The last required covariance matrix.',...
 '# ',...
+'#<SXINVn> The inverse of SX. An optional field, see further ABS_SPECIES.',...
+'# ',...
 '#<L2> Flag for any function creating L2 data. See comments for ',...
 '*L2_EXTRA*. If set to true, the retrieved baseline variables ',...
 'will be included in the L2 output. Otherwise not. This field has no ',...
@@ -824,6 +864,8 @@ I.T = [ ...
 'match the grid field. Data must match <UNIT>. A matrix, that can be ',...
 'sparse.',...
 '# ',...
+'#<SXINV> The inverse of SX. An optional field, see further ABS_SPECIES.',...
+'# ',...
 '#<L2> Flag for any function creating L2 data. See comments for ',...
 '*L2_EXTRA*. If set to true, the retrieved state for temperature ',...
 'will be included in the L2 output. Otherwise not.',...
@@ -837,12 +879,6 @@ I.T = [ ...
 'Default here is "on". This refers only to the actual jacobian calculation.',...
 ' If the atmosphere itself fulfils HSE or not is controlled by Q.HSE.',...
 '# ',...
-'#<METHOD> As the argument to *jacobianAddTemperature* with same name. ',...
-'Default here is "analytical".',...
-'# ',...
-'#<DT> As the argument to *jacobianAddTemperature* with same name. ',...
-'Default here is 1 K.',...
-'# ',...
 '#None of the fields are mandatory for pure forward calculations. If ',...
 'RETRIEVAL is set to false, the other retrieval related fields are ignored.'
 ];  
@@ -901,22 +937,27 @@ I.WIND_U = [ ...
 'through *gf_save*. ',...
 'This field is recognised and used automatically by Qpack2.',...
 '# ',...
-'#<RETRIEVE> If set to true, this atmospheric wind is retrieved.', ...
+'#<RETRIEVE> If set to true, this atmospheric wind component is retrieved.', ...
 '# ',...
 '#<GRIDS> Retrieval grids for the wind. An array of vectors of length 3:',...
 ' {p_grid,lat_grid,lon_grid}. Grids for dimensions not used shall be ',...
 'empty.',...
 '# ',...
-'#<SX> Covariance matrix of a priori knowledge for temperature. Size must ',...
+'#<SX> Covariance matrix of a priori knowledge. Size must ',...
 'match the grid field. Data must match <UNIT>. A matrix, that can be ',...
 'sparse.',...
 '# ',...
+'#<SXINV> The inverse of SX. An optional field, see further ABS_SPECIES.',...
+'# ',...
 '#<L2> Flag for any function creating L2 data. See comments for ',...
 '*L2_EXTRA*. If set to true, the retrieved state for this wind component ',...
 'will be included in the L2 output. Otherwise not.',...
 '# ',...
 '#<L2_RANGE>  As the same field for ABS_SPECIES.',...
 '# ',...
+'#<MINMAX> Min and max allowed value for retrievals. Works exactly as ',...
+'for ABS_SPECIES.',...
+'# ',...
 '#None of the fields are mandatory for pure forward calculations. If ',...
 'RETRIEVAL is set to false, the other retrieval related fields are ignored.'
 ];  
