@@ -17,12 +17,12 @@
 
 function result = xmlReadTensor6(fid, attrlist, itype, ftype, binary, fid2)
 
-nv = str2num (xmlGetAttrValue (attrlist, 'nvitrines'));
-ns = str2num (xmlGetAttrValue (attrlist, 'nshelves'));
-nb = str2num (xmlGetAttrValue (attrlist, 'nbooks'));
-np = str2num (xmlGetAttrValue (attrlist, 'npages'));
-nr = str2num (xmlGetAttrValue (attrlist, 'nrows'));
-nc = str2num (xmlGetAttrValue (attrlist, 'ncols'));
+nv = str2double (xmlGetAttrValue (attrlist, 'nvitrines'));
+ns = str2double (xmlGetAttrValue (attrlist, 'nshelves'));
+nb = str2double (xmlGetAttrValue (attrlist, 'nbooks'));
+np = str2double (xmlGetAttrValue (attrlist, 'npages'));
+nr = str2double (xmlGetAttrValue (attrlist, 'nrows'));
+nc = str2double (xmlGetAttrValue (attrlist, 'ncols'));
 nelem =  nv * ns * nb * np * nr * nc;
 
 if ~binary
