@@ -19,17 +19,22 @@ xmlWriteTag (fid, 'Ppath', []);
 xmlWriteIndex (fid, fidb, data.dim, precision);
 xmlWriteIndex (fid, fidb, data.np, precision);
 xmlWriteNumeric (fid, fidb, data.constant, precision);
+xmlWriteString (fid, fidb, data.background, precision);
+xmlWriteVector (fid, fidb, data.start_pos, precision);
+xmlWriteVector (fid, fidb, data.start_los, precision);
+xmlWriteNumeric (fid, fidb, data.start_lstep, precision);
 xmlWriteMatrix (fid, fidb, data.pos, precision);
-xmlWriteVector (fid, fidb, data.z, precision);
-xmlWriteVector (fid, fidb, data.l_step, precision);
+xmlWriteMatrix (fid, fidb, data.los, precision);
+xmlWriteVector (fid, fidb, data.r, precision);
+xmlWriteVector (fid, fidb, data.lstep, precision);
+xmlWriteVector (fid, fidb, data.end_pos, precision);
+xmlWriteVector (fid, fidb, data.end_los, precision);
+xmlWriteNumeric (fid, fidb, data.end_lstep, precision);
+xmlWriteVector (fid, fidb, data.nreal, precision);
+xmlWriteVector (fid, fidb, data.ngroup, precision);
 xmlWriteArrayOf (fid, fidb, data.gp_p, 'GridPos', precision);
 xmlWriteArrayOf (fid, fidb, data.gp_lat, 'GridPos', precision);
 xmlWriteArrayOf (fid, fidb, data.gp_lon, 'GridPos', precision);
-xmlWriteMatrix (fid, fidb, data.los, precision);
-xmlWriteString (fid, fidb, data.background, precision);
-xmlWriteVector (fid, fidb, data.tan_pos, precision);
-xmlWriteVector (fid, fidb, data.geom_tan_pos, precision);
-xmlWriteVector (fid, fidb, data.nreal, precision);
 
 xmlWriteCloseTag (fid, 'Ppath');
 
