@@ -94,7 +94,7 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
     %
     % Don't forget the Collocation User's Guide.
 
-    % $Id: SatDataset.m 8777 2014-02-12 12:45:13Z gerrit $
+    % $Id: SatDataset.m 9897 2016-08-01 18:28:41Z gerrit $
     
     % read/write props
     properties
@@ -562,7 +562,7 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
             %
             %   >> [grans, paths] = mhs.find_granules_by_date([2010, 9, 8], 'noaa18');
             %
-            % $Id: SatDataset.m 8777 2014-02-12 12:45:13Z gerrit $
+            % $Id: SatDataset.m 9897 2016-08-01 18:28:41Z gerrit $
             
             % errid = 'atmlab:find_granules_by_date';
             
@@ -845,7 +845,7 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
             %
             %   >> data = mhs.read_granule([2010 9 8 8 8], 'noaa18', {}, true, false);
             %
-            % $Id: SatDataset.m 8777 2014-02-12 12:45:13Z gerrit $
+            % $Id: SatDataset.m 9897 2016-08-01 18:28:41Z gerrit $
              
             % optional arguments
             [spec, fields_asked, remdouble, force, reload] = optargs(varargin, {'', {}, true, false, false});
@@ -873,13 +873,20 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
             vn = genvarname(DataHash([self.name, date, varargin]));
             
             %% read cached if appropiate
-            if ~reload && ~isempty(self.cache) && self.cache.has_entry(vn)
-                logtext(atmlab('OUT'), 'Reading %s from cache (entry %s)\n', ...
-                    self.name, vn);
-                data = self.cache.get_entry(vn);
-                return
+            if ~reload
+                if ~isempty(self.cache) && self.cache.has_entry(vn)
+                    logtext(atmlab('OUT'), 'Reading %s from cache (entry %s)\n', ...
+                        self.name, vn);
+                    data = self.cache.get_entry(vn);
+                    return
+                end
+                if isfield(self,'pcd') && ~isempty(self.pcd) && self.pcd.has_entry(vn)
+%                     logtext(atmlab('OUT'), 'Reading %s from cache (entry %s)\n', ...
+%                         self.name, vn);
+                    data = self.pcd.get_entry(vn);
+                    return
+                end
             end
-            
             %% find datafile and function to read it
             datafile = self.find_granule_by_datetime(date, spec);
             
@@ -928,6 +935,7 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
                          'id ''%s'', message ''%s''.  See ''cause'' for details.'], ...
                          class(self), self.name, datafile, ME.identifier, ME.message);
                     ME2 = ME2.addCause(ME);
+%                    keyboard
                     ME2.throw();
                 end
             end
@@ -1000,6 +1008,8 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
             %% cache results
             if ~isempty(self.cache)
                 self.cache.set_entry(vn, data);
+            elseif ~isempty(self.pcd)
+                self.pcd.set_entry(vn, data);
             end
         end
                 
@@ -1401,6 +1411,7 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
             % date2
             % spec
             % fields
+            %   Cell array.  Names of fields to be considered.
             % gridsize
             % (optional) limiters
             %   Cell array.  Each element is either a function handle
@@ -1417,11 +1428,16 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
             % - gridmean: 3-D matrix, [nlat nlon nfield]
             %
             % FIXME DOC
+            %
+            % TODO: think of a way to process
+            % multi-dimensional fields, i.e. tb [2457x90x5]
             
             [limiters, data] = optargs(varargin, {{}, struct()});
             %data.gridsize = gridsize;
             allgrans = self.find_granules_for_period(date1, date2, spec);
             allstats = {};
+            lat = -90:gridsize:90;
+            lon = -180:gridsize:180;
             % sort limiters
             if ~iscell(limiters)
                 limiters = {limiters};
@@ -1445,9 +1461,12 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
             i = 0;
             while i < size(allgrans, 1)
                 
+                data = struct();
                 data.lat = zeros(1e6, 1, 'single');
                 data.lon = zeros(1e6, 1, 'single');
-                data.data = zeros(1e6, length(fields), 'single');
+%                data.data = zeros(1e6, ...
+%                    sum(cellfun(@(f)size(grandata.(f), 3), fields)), ...
+%                    'single');
                 
                 N = 1;
                 X = whos('data');
@@ -1457,7 +1476,8 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
                         grandata = self.read_granule(allgrans(i, :), spec, union(fields, also_fields));
                     catch ME
                         switch ME.identifier
-                            case 'atmlab:SatDataset:cannotread'
+                            case {'atmlab:SatDataset:cannotread',...
+                                  'atmlab:find_granule_by_datetime'}
                                 logtext(atmlab('ERR'), ...
                                     'Cannot read granule: %s', ...
                                     ME.identifier);
@@ -1466,6 +1486,23 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
                                 ME.rethrow();
                         end
                     end
+                    % first time, allocate data.  width depends on fields
+                    
+%                    found = false; nonGeoDim = 1;
+                    nonGeoDim = find(size(grandata.lat)>1,1, 'last') + 1;
+%                    while ~found
+%                        if numel(data.lat)==size(data.lat,nonGeoDim), found = true; end
+%                        nonGeoDim = nonGeoDim + 1;
+%                    end
+
+                    % for all fields, sum first dimension AFTER lat/lon
+                    % dimensions
+                    if ~isfield(data, 'data')
+                        data.data = zeros(1e6, ...
+                            sum(cellfun(@(f)size(grandata.(f), nonGeoDim), fields)), ...
+                            'single');
+                    end
+
                     % apply limiters
                     mask = true(size(grandata.lat));
                     for k = 1:length(limit_other)
@@ -1476,7 +1513,31 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
                     grandata.lon = grandata.lon(mask);
                     for k = 1:length(fields)
                         field = fields{k};
-                        grandata.(field) = grandata.(field)(mask);                    
+%                        if ndims(grandata.(field)) <= nonGeoDim-1
+                        if numel(grandata.(field)) == numel(mask)
+                            grandata.(field) = grandata.(field)(mask);
+                        else
+                            % process multi-dimensional fields, i.e. tb [2457x90x5]
+%                            if ndims(grandata.(field)) > nonGeoDim
+%                                error(['atmlab:' mfilename ':NotImplemented'], ...
+%                                    'I cannot handle %d dimensions for %s!', ...
+%                                    ndims(grandata.(field)), field);
+%                            end
+                            if ndims(grandata.(field)) == 3
+                                grandata.(field) = arrayfun(@(i)(par(grandata.(field)(:, :, i), ...
+                                    mask)), 1:size(grandata.(field), 3), ...
+                                    'UniformOutput', false);
+%                            elseif nonGeoDim == 2
+%                                grandata.(field) = arrayfun(@(i)(par(grandata.(field)(:, i), ...
+%                                    mask)), 1:size(grandata.(field), nonGeoDim), ...
+%                                    'UniformOutput', false);
+                            else
+                                error(['atmlab:' mfilename ':NotImplemented'], ...
+                                    'Sorry, can''t handle %d dimensions for %s!', ...
+                                    ndims(grandata.(field)), field);
+                            end
+                            grandata.(field) = horzcat(grandata.(field){:});
+                        end
                     end
                         
                     nnew = size(grandata.lat, 1);
@@ -1488,7 +1549,8 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
                         % double allocation
                         data.lat = [data.lat; zeros(size(data.lat, 1), 1, 'single')];
                         data.lon = [data.lon; zeros(size(data.lon, 1), 1, 'single')];
-                        data.data = [data.data; zeros(size(data.data, 1), length(fields), 'single')];
+                        data.data = [data.data; ...
+                            zeros(size(data.data, 1), size(data.data, 2), 'single')];
                     end
                     data.lat(new) = grandata.lat;
                     data.lon(new) = grandata.lon;
@@ -1501,7 +1563,7 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
                 end
                 data.lat = data.lat(1:N-1);
                 data.lon = data.lon(1:N-1);
-                data.data = data.data(1:N-1);
+                data.data = data.data(1:N-1, :);
                 
 %                 data.lat = grandata.lat;
 %                 data.lon = grandata.lon;
@@ -1509,9 +1571,16 @@ classdef SatDataset < handle % subclass from handle to pass-by-reference
 %                 data.data = horzcat(C{:});
                 logtext(atmlab('OUT'), 'Binning\n');
                 %[binned, lat, lon] = binning_fast(data);
-                indces = bin_nd({data.lat, data.lon}, {-90:gridsize:90, -180:gridsize:180});
-                binned = cellfun(@(ii) data.data(ii), indces, 'UniformOutput', false);
-                stats = binned_statistics(binned, {@(x)(size(x,1)), @(x)(sum(x,1))}, limit_binnedstats);
+                indces = bin_nd({data.lat, data.lon}, {lat, lon});
+                binned = cellfun(@(ii) data.data(ii, :), indces, 'UniformOutput', false);
+                
+                % SE: added replace = zeros(1,size(data.data,nonGeoDim)),
+                % because cell2mat doesn't like cells being empty, and doesn't
+                % like the cells containing diffent dimensions
+                stats = binned_statistics(binned, {@(x)(size(x,1)), @(x)(sum(x,1))},...
+                    limit_binnedstats,...
+                    {0,zeros(1,size(data.data,2))},... %replace
+                    struct('dataClass',class(binned{1,1})));
                 logtext(atmlab('OUT'), 'Calculating statistics\n');
                 stats.statistic1 = cell2mat(stats.statistic1);
                 % cell2mat on multi-dim will flatten 2nd dimension,
