@@ -9,10 +9,10 @@ function command = grdcontour(file,in)
 % OUT   command   %s              string command to be used in system call
 %
 % Created by Salomon Eliasson
-% $Id: grdcontour.m 8362 2013-04-20 18:30:35Z seliasson $
+% $Id: grdcontour.m 9251 2015-03-23 20:09:59Z seliasson $
 
 %location of file, region and projection
-grdcontour = sprintf('grdcontour %s -R -J',in.grdfile);
+grdcontour = sprintf('gmt grdcontour %s -R -J',in.grdfile);
 
 grdcontour = sprintf('%s %s',grdcontour,in.plotPlacement);
 
@@ -21,7 +21,7 @@ if isfield(in,'spacing')
 end
 
 if isfield(in,'fontsize')
-    grdcontour = sprintf('%s+s%g',grdcontour,num2str(in.fontsize));
+    grdcontour = sprintf('%s+f%g',grdcontour,num2str(in.fontsize));
 end
 
 if isfield(in,'range')
